@@ -1,3 +1,9 @@
+SELECT setting::integer < 130000 AS pre_13
+FROM pg_settings WHERE name = 'server_version_num';
+
+/* Run tests as unprivileged user */
+SET ROLE TO periods_unprivileged_user;
+
 /* Basic period definitions with dates */
 CREATE TABLE basic (val text, s date, e date);
 TABLE periods.periods;
